==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebNavDrawerHeaderItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerHeaderItemDescription } from "./WebNavDrawerHeaderItemDescription";
/**
 * @hidden
 */
var WebNavDrawerHeaderItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebNavDrawerHeaderItemDescriptionMetadata, _super);
    function WebNavDrawerHeaderItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerHeaderItemDescriptionMetadata.b = function (a) {
        if (WebNavDrawerHeaderItemDescriptionMetadata.a == null) {
            WebNavDrawerHeaderItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerHeaderItemDescriptionMetadata.c(WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
        if (a.j(WebNavDrawerHeaderItemDescriptionMetadata.a)) {
            return;
        }
        a.y(WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawerHeaderItem");
        a.item("__tagNameWC", "String:igc-nav-drawer-header-item");
    };
    WebNavDrawerHeaderItemDescriptionMetadata.d = function (a) {
        WebNavDrawerHeaderItemDescriptionMetadata.b(a);
        a.aa("WebNavDrawerHeaderItem", function () { return new WebNavDrawerHeaderItemDescription(); });
        a.z("WebNavDrawerHeaderItem", WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.$t = markType(WebNavDrawerHeaderItemDescriptionMetadata, 'WebNavDrawerHeaderItemDescriptionMetadata');
    WebNavDrawerHeaderItemDescriptionMetadata.a = null;
    return WebNavDrawerHeaderItemDescriptionMetadata;
}(Base));
export { WebNavDrawerHeaderItemDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebNavDrawerHeaderItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerHeaderItemDescription } from "./WebNavDrawerHeaderItemDescription";
/**
 * @hidden
 */
var WebNavDrawerHeaderItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebNavDrawerHeaderItemDescriptionMetadata, _super);
    function WebNavDrawerHeaderItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerHeaderItemDescriptionMetadata.b = function (a) {
        if (WebNavDrawerHeaderItemDescriptionMetadata.a == null) {
            WebNavDrawerHeaderItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerHeaderItemDescriptionMetadata.c(WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
        if (a.k(WebNavDrawerHeaderItemDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawerHeaderItem");
        a.item("__tagNameWC", "String:igc-nav-drawer-header-item");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebNavDrawerHeaderItemDescriptionMetadata.d = function (a) {
        WebNavDrawerHeaderItemDescriptionMetadata.b(a);
        a.ac("WebNavDrawerHeaderItem", function () { return new WebNavDrawerHeaderItemDescription(); });
        a.ab("WebNavDrawerHeaderItem", WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.$t = markType(WebNavDrawerHeaderItemDescriptionMetadata, 'WebNavDrawerHeaderItemDescriptionMetadata');
    WebNavDrawerHeaderItemDescriptionMetadata.a = null;
    return WebNavDrawerHeaderItemDescriptionMetadata;
}(Base));
export { WebNavDrawerHeaderItemDescriptionMetadata };
